@@ -6,7 +6,7 @@ use quantity::python::{PySIArray2, PySINumber};
 use quantity::si::*;
 
 /// A collection of external potentials.
-#[pyclass(name = "ExternalPotential", unsendable)]
+#[pyclass(name = "ExternalPotential")]
 #[derive(Clone)]
 pub struct PyExternalPotential(pub ExternalPotential<SIUnit>);
 
@@ -184,7 +184,7 @@ impl PyExternalPotential {
     ///     The cartesian coordinates of the center of the pore
     /// system_size : [SINumber; 3]
     ///     The size of the unit cell.
-    /// n_grid : [int; 3]
+    /// n_grid : [int; 2]
     ///     The number of grid points in each direction.
     /// Returns
     /// -------
@@ -222,7 +222,7 @@ impl PyExternalPotential {
 /// Returns
 /// -------
 /// Geometry
-#[pyclass(name = "Geometry", unsendable)]
+#[pyclass(name = "Geometry")]
 #[derive(Clone)]
 pub struct PyGeometry(pub AxisGeometry);
 
